@@ -1,6 +1,7 @@
 import tensorflow as tf
+import tensorflow.keras.backend as K
 
-from tensorflow.keras.layers import Dense, Conv2D
+from tensorflow.keras.layers import Dense, Conv2D, Wrapper
 from tensorflow.keras.layers import ReLU, BatchNormalization, Flatten, MaxPool2D, Input
 
 
@@ -12,7 +13,7 @@ class DropConnectDense(Dense):
     def __init__(self, *args, **kwargs):
         self.prob = kwargs.pop('prob', 0.5)
         if not 0. <= self.prob < 1.:
-            raise NameError('prob must be at range [0, 1]]')
+            raise NameError('prob must be at range [0, 1)]')
 
 
         super(DropConnectDense, self).__init__(*args, **kwargs)
@@ -43,7 +44,7 @@ class DropConnectConv2D(Conv2D):
     def __init__(self, *args, **kwargs):
         self.prob = kwargs.pop('prob', 0.5)
         if not 0. <= self.prob < 1.:
-            raise NameError('prob must be at range [0, 1]]')
+            raise NameError('prob must be at range [0, 1)]')
 
         super(DropConnectConv2D, self).__init__(*args, **kwargs)
 
@@ -75,3 +76,36 @@ class DropConnectConv2D(Conv2D):
         if self.use_bias:
             output = tf.nn.bias_add(output, self.bias)
         return self.activation(output)
+
+
+
+
+
+class DropConnect(Wrapper):
+    def __init__(self, layer, prob=0.0, **kwargs):
+
+        if not 0. <= prob < 1.:
+            raise NameError('prob must be at range [0, 1)]')
+
+        self.prob = prob
+        self.layer = layer
+  
+        super(DropConnect, self).__init__(layer, **kwargs)
+
+    def build(self, input_shape):
+        if not self.layer.built:
+            self.layer.build(input_shape)
+            self.layer.built = True
+
+        self.n_trainable = len(self.layer.trainable_weights)
+
+        super(DropConnect, self).build()
+
+    def compute_output_shape(self, input_shape):
+        return self.layer.compute_output_shape(input_shape)
+
+    def call(self, x):
+        for counter in range(self.n_trainable):
+            self.layer.trainable_weights[counter] = K.in_train_phase(K.dropout(self.layer.trainable_weights[counter], self.prob),
+                                                                     self.layer.trainable_weights[counter] * (1-self.prob))
+        return self.layer.call(x)
\ No newline at end of file
